PdfDest class
PDF Explicit Destination the page and inner-page location to jump to.
Constructors
Properties
- command → PdfDestCommand
-
Destination command.
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- pageNumber → int
-
Page number to jump to.
final
-
params
→ List<
double?> ? -
Destination parameters. For more info, see PdfDestCommand.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
compact(
) → PdfDest - Compact the destination.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override