PdfDocumentRefAsset class

A PdfDocumentRef that loads the document from asset.

Inheritance

Constructors

PdfDocumentRefAsset(String name, {PdfPasswordProvider? passwordProvider, bool firstAttemptByEmptyPassword = true, bool autoDispose = true, bool useProgressiveLoading = true, PdfDocumentRefKey? key})

Properties

autoDispose bool
Whether to dispose the document on reference dispose or not.
finalinherited
firstAttemptByEmptyPassword bool
firstAttemptByEmptyPassword is used to determine whether the first attempt to open the PDF is by empty password or not. For more info, see PdfPasswordProvider.
final
hashCode int
The hash code for this object.
no setterinherited
key PdfDocumentRefKey
A name that identifies the source of the document.
finalinherited
name String
final
passwordProvider PdfPasswordProvider?
passwordProvider is used to provide password for encrypted PDF. See PdfPasswordProvider for more info.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sourceName String
The name that identifies the source of the document.
no setterinherited
useProgressiveLoading bool
Whether to use progressive loading or not.
final

Methods

loadDocument(PdfDocumentLoaderProgressCallback progressCallback) Future<PdfDocument>
Use resolveListenable/PdfDocumentListenable.document instead to load the shared PdfDocument.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
resolveListenable() PdfDocumentListenable
Resolve the PdfDocumentListenable for this reference.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited