PdfDocumentViewBuilder class

A widget that loads PDF document.

The following fragment shows how to display a PDF document from an asset:

PdfDocumentViewBuilder.asset(
  'assets/sample.pdf',
  builder: (context, document) => ListView.builder(
    itemCount: document?.pages.length ?? 0,
    itemBuilder: (context, index) {
      return Container(
        margin: const EdgeInsets.all(8),
        height: 240,
        child: Column(
          children: [
            SizedBox(
              height: 220,
              child: PdfPageView(
                document: document,
                pageNumber: index + 1,
              ),
            ),
            Text('${index + 1}'),
          ],
        ),
      );
    },
  ),
),
Inheritance

Constructors

PdfDocumentViewBuilder({required PdfDocumentRef documentRef, required PdfDocumentViewBuilderFunction builder, WidgetBuilder? loadingBuilder, PdfDocumentViewBuilderErrorBuilder? errorBuilder, Key? key})
Creates a widget that loads PDF document.
const
PdfDocumentViewBuilder.asset(String assetName, {required PdfDocumentViewBuilderFunction builder, WidgetBuilder? loadingBuilder, PdfDocumentViewBuilderErrorBuilder? errorBuilder, Key? key, PdfPasswordProvider? passwordProvider, bool firstAttemptByEmptyPassword = true, bool useProgressiveLoading = false, bool autoDispose = true})
Creates a widget that loads PDF document from an asset.
PdfDocumentViewBuilder.file(String filePath, {required PdfDocumentViewBuilderFunction builder, WidgetBuilder? loadingBuilder, PdfDocumentViewBuilderErrorBuilder? errorBuilder, Key? key, PdfPasswordProvider? passwordProvider, bool firstAttemptByEmptyPassword = true, bool useProgressiveLoading = false, bool autoDispose = true})
Creates a widget that loads PDF document from a file.
PdfDocumentViewBuilder.uri(Uri uri, {required PdfDocumentViewBuilderFunction builder, WidgetBuilder? loadingBuilder, PdfDocumentViewBuilderErrorBuilder? errorBuilder, Key? key, PdfPasswordProvider? passwordProvider, bool firstAttemptByEmptyPassword = true, bool useProgressiveLoading = false, bool autoDispose = true, bool preferRangeAccess = false, Map<String, String>? headers, bool withCredentials = false})
Creates a widget that loads PDF document from a URI.

Properties

builder PdfDocumentViewBuilderFunction
The builder that builds the widget tree with the PDF document.
final
documentRef PdfDocumentRef
The reference to the PDF document.
final
errorBuilder PdfDocumentViewBuilderErrorBuilder?
The builder that builds the error widget on error.
final
hashCode int
The hash code for this object.
no setterinherited
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
loadingBuilder WidgetBuilder?
The builder that builds the loading widget.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

createElement() StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() State<PdfDocumentViewBuilder>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited