PdfFontLoadResult class

Constructors

PdfFontLoadResult({required List<PdfLoadedFont> loaded, required List<PdfFontQuery> unresolved, required List<PdfFontLoadFailure> failed, required bool fontsReloaded})
const

Properties

failed List<PdfFontLoadFailure>
List of queries that threw errors during resolution or loading.
final
fontsReloaded bool
Whether PdfrxEntryFunctions.reloadFonts was called after registering fonts.
final
hashCode int
The hash code for this object.
no setterinherited
hasLoadedFonts bool
Whether any fonts were successfully loaded.
no setter
loaded List<PdfLoadedFont>
List of fonts newly loaded and registered by this call.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
unresolved List<PdfFontQuery>
List of queries that could not be resolved by any resolver.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited