PdfFontManager class

Registers resolved missing fonts through PdfrxEntryFunctions.

Constructors

PdfFontManager({required List<PdfFontResolver> resolvers})
Creates a PdfFontManager with the given list of resolvers.
PdfFontManager.linux({List<PdfFontResolver> resolvers = const []})
Creates a font manager that prefers Linux system fonts.
factory
PdfFontManager.macos({List<PdfFontResolver> resolvers = const []})
Creates a font manager that prefers macOS system fonts.
factory
PdfFontManager.platform({List<PdfFontResolver> resolvers = const []})
Creates a font manager for the current desktop platform.
factory
PdfFontManager.windows({List<PdfFontResolver> resolvers = const []})
Creates a font manager that prefers Windows system fonts.
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

loadMissingFonts(Iterable<PdfFontQuery> queries, {PdfFontResolveContext context = const PdfFontResolveContext(), bool reloadFonts = true, PdfFontLoadProgressCallback? onProgress}) Future<PdfFontLoadResult>
Resolves and registers queries.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
prepare({String? fontCachePath, List<String>? fontPaths}) Future<void>
Prepares the backend font environment.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited