PdfLinkHandlerParams class

Parameters to customize link handling/appearance.

Constructors

PdfLinkHandlerParams({required void onLinkTap(PdfLink link), Color? linkColor, PdfLinkCustomPagePainter? customPainter, bool enableAutoLinkDetection = true, bool laidOverPageOverlays = true})
const

Properties

customPainter PdfLinkCustomPagePainter?
Custom link painter for the page.
final
enableAutoLinkDetection bool
Whether to try to detect Web links automatically or not. This is useful if the PDF file contains text that looks like Web links but not defined as links in the PDF. The default is true.
final
hashCode int
The hash code for this object.
no setteroverride
laidOverPageOverlays bool
Whether the link widgets are laid over page overlays or not.
final
linkColor Color?
Color for the link. If null, the default color is Colors.blue.withValue(alpha: 0.2).
final
onLinkTap → void Function(PdfLink link)
Function to be called when the link is tapped.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(covariant PdfLinkHandlerParams other) bool
The equality operator.
override