PdfPageTextRange class

Text range in a PDF page, which is typically used to describe text selection.

Constructors

PdfPageTextRange({required PdfPageText pageText, required int start, required int end})
Create a PdfPageTextRange.
const

Properties

bounds PdfRect
The bounding rectangle of the text range in PDF page coordinates.
no setter
end int
Text end index in PdfPageText.fullText.
final
firstFragment PdfPageTextFragment?
Get the first text fragment in the range.
no setter
firstFragmentIndex int
Get the first text fragment index corresponding to the text range.
no setter
hashCode int
The hash code for this object.
no setteroverride
lastFragment PdfPageTextFragment?
Get the last text fragment in the range.
no setter
lastFragmentIndex int
Get the last text fragment index corresponding to the text range.
no setter
pageNumber int
Page number of the text range.
no setter
pageText PdfPageText
The page text the text range are associated with.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
start int
Text start index in PdfPageText.fullText.
final
text String
The composed text of the text range.
no setter

Methods

enumerateFragmentBoundingRects() Iterable<PdfTextFragmentBoundingRect>
Enumerate all the fragment bounding rectangles for the text range.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override