PdfViewerCoordinateConverter class abstract

Utility class to convert document coordinates to local coordinates and vice versa.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
offsetToDocument(BuildContext context, Offset? position) Offset?
Convert a local position in the specified context to a document position.
offsetToLocal(BuildContext context, Offset? position) Offset?
Convert a document position to a local position in the specified context.
rectToDocument(BuildContext context, Rect? rect) Rect?
Convert a local rectangle in the specified context to a document rectangle.
rectToLocal(BuildContext context, Rect? rect) Rect?
Convert a document rectangle to a local rectangle in the specified context.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited