rectToLocal abstract method
Convert a document rectangle to a local rectangle in the specified context.
Implementation
Rect? rectToLocal(BuildContext context, Rect? rect);
Convert a document rectangle to a local rectangle in the specified context.
Rect? rectToLocal(BuildContext context, Rect? rect);