PdfViewerHandleLinkTap typedef

PdfViewerHandleLinkTap = bool Function(Offset position)

Function to handle link tap.

The function returns true if it processes the link on the specified position; otherwise, returns false. position is the position of the tap in the viewer; typically it is GestureDetector.onTapUp's TapUpDetails.localPosition.

Implementation

typedef PdfViewerHandleLinkTap = bool Function(Offset position);