PdfViewerLayoutMetrics class
A container for the calculated scaling limits of the viewer.
Returned by PdfViewerSizeDelegate.calculateMetrics.
Constructors
- PdfViewerLayoutMetrics({required double minScale, required double maxScale, required double coverScale, double? alternativeFitScale})
-
const
Properties
- alternativeFitScale → double?
-
The scale required to fit the content (usually the current page) entirely within the viewport.
final
- coverScale → double
-
The scale required to fit the document's bounding box within the viewport.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- maxScale → double
-
The effective maximum scale allowed for the viewer.
final
- minScale → double
-
The effective minimum scale allowed for the viewer.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited