scrollPhysics property

ScrollPhysics? scrollPhysics
final

Scroll physics for the viewer.

If null, default InteractiveViewer physics is used on all platforms. This physics clamps to boundaries, does not allow zooming beyond the min/max scale, and flings on panning come to rest quickly relative to Scrollables in Flutter (such as SingleChildScrollView).

A convenience function getScrollPhysics is provided to get platform-specific default scroll physics. If you want no overscroll, but still want the physics for panning to be similar to other Scrollables, you can use ClampingScrollPhysics.

If the value is set non-null, it disables normalizeMatrix.

If you set boundaryMargin to EdgeInsets.all(double.infinity), this will enable scrolling beyond the boundaries regardless of which ScrollPhysics is used.

Implementation

final ScrollPhysics? scrollPhysics;