PdfViewerScrollThumb class

Scroll thumb for PdfViewer.

Use with PdfViewerParams.viewerOverlayBuilder to add scroll thumbs to the viewer.

Inheritance

Constructors

PdfViewerScrollThumb({required PdfViewerController controller, ScrollbarOrientation orientation = ScrollbarOrientation.right, Size? thumbSize, double margin = 2, Widget? thumbBuilder(BuildContext context, Size thumbSize, int? pageNumber, PdfViewerController controller)?, Key? key})
const

Properties

controller → PdfViewerController
PdfViewerController attached to the PdfViewer.
final
hashCode → int
The hash code for this object.
no setterinherited
isVertical → bool
Determine whether the orientation is vertical or not.
no setter
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
margin → double
Margin from the viewer's edge.
final
orientation → ScrollbarOrientation
Position/Orientation of the scroll thumb.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
thumbBuilder → Widget? Function(BuildContext context, Size thumbSize, int? pageNumber, PdfViewerController controller)?
Function to customize the thumb widget.
final
thumbSize → Size?
Size of the scroll thumb.
final

Methods

createElement() → StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() → State<PdfViewerScrollThumb>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited