PdfFontResolver class abstract
Resolves missing PDF fonts to font data that can be registered to pdfrx.
This API is experimental. Font loading is inherently asynchronous on some platforms, especially Web and Apple platforms, so callers should expect to reload already opened documents after new font data is registered.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
resolve(
PdfFontQuery query, PdfFontResolveContext context) → FutureOr< PdfFontResolution?> -
Returns a font resolution for
query, or null if this resolver cannot satisfy the request. Implementations should not throw errors for unsupported queries, but they can throw errors for queries they are expected to support but fail to resolve (e.g. due to network issues when fetching font data from a remote server). -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited