PdfPageStatusChange class abstract
Base class for PDF page status change.
Constructors
- PdfPageStatusChange()
-
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- page → PdfPage
-
The page that has changed.
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- type → PdfPageStatusChangeType
-
Type of the status change.
no setter
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
modified(
{required PdfPage page}) → PdfPageStatusChange - Return PdfPageStatusModified.
-
moved(
{required PdfPage page, required int oldPageNumber}) → PdfPageStatusChange - Create PdfPageStatusMoved.