PdfViewerCalculateZoomFunction typedef
PdfViewerCalculateZoomFunction =
double? Function(PdfDocument document, PdfViewerController controller, double fitZoom, double coverZoom)
Function to calculate the initial zoom level.
If the function returns null, the viewer will use the default zoom level. You can use the following parameters to calculate the zoom level:
fitZoomis the zoom level to fit the "initial" page into the viewer.coverZoomis the zoom level to cover the entire viewer with the "initial" page.
Implementation
typedef PdfViewerCalculateZoomFunction =
double? Function(PdfDocument document, PdfViewerController controller, double fitZoom, double coverZoom);