PdfViewerZoomStepsDelegate class abstract
Delegate to determine the "Zoom Stops" (snap points) for the viewer.
Zoom stops are primarily used for:
- Double-tap zooming: Cycling through specific levels (e.g. Fit Page -> Fit Width -> 100%).
- Accessibility/Keyboard: Incrementing zoom levels via shortcuts.
This delegate decouples the Interaction Policy (which zoom levels are "interesting"?) from the Sizing Policy (what are the hard limits?).
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
dispose(
) → void - Called when the delegate is being destroyed.
-
generateZoomStops(
PdfViewerLayoutMetrics metrics) → List< double> - Generates the list of zoom stops (steps) for user interaction.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited